from starlette.requests import Request
from starlette.responses import RedirectResponse, JSONResponse

from api.route import Route
from core.environment import Environment
from core.logger import Logger
from data.schemas.public.user_space_user import UserSpaceUser
from data.schemas.public.user_space_user_dao import userSpaceUserDao

BasePath = f"/invitation"
logger = Logger(__name__)


@Route.get(f"{BasePath}/accept/{{invitation_id:path}}")
async def accept_invitation(request: Request):
    invitation_id = request.path_params["invitation_id"]

    user_space_user = await userSpaceUserDao.find_single_by(
        [{UserSpaceUser.invitation: invitation_id}, {UserSpaceUser.deleted: False}]
    )
    if user_space_user is None:
        return JSONResponse({"error": "Invitation not found or already accepted."})

    user_space_user.invitation = None
    await userSpaceUserDao.update(user_space_user)

    client_urls = Environment.get("CLIENT_URLS", str)
    if client_urls is None:
        return JSONResponse(
            {"message": "Invitation accepted, but no client URLs configured."}
        )

    return RedirectResponse(client_urls.split(",")[0], status_code=303)
